@@ -1,4 +1,4 @@
-from fuocore.dispatch import Signal
+from feeluown.utils.dispatch import Signal
 from feeluown.widgets.my_music import MyMusicModel
 
 
