@@ -1,7 +1,7 @@
 from PyQt5.QtCore import pyqtSignal
 from PyQt5.QtWidgets import QHBoxLayout, QComboBox, QWidget
 
-from fuocore.models import AlbumType
+from feeluown.models import AlbumType
 from feeluown.widgets import TextButton
 
 
@@ -13,7 +13,9 @@ class SongsTableToolbar(QWidget):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self.play_all_btn = TextButton('Play All', self)
+        self._tmp_buttons = []
+
+        self.play_all_btn = TextButton('播放全部', self)
         self.play_all_btn.clicked.connect(self.play_all_needed.emit)
 
         self.play_all_btn.setObjectName('play_all')
@@ -28,11 +30,6 @@ class SongsTableToolbar(QWidget):
         self.filter_albums_combobox.hide()
         self._setup_ui()
 
-    def _before_change_mode(self):
-        """filter all filter buttons"""
-        self.filter_albums_combobox.hide()
-        self.play_all_btn.hide()
-
     def albums_mode(self):
         self._before_change_mode()
         self.filter_albums_combobox.show()
@@ -49,12 +46,19 @@ class SongsTableToolbar(QWidget):
         # currently, this is called only when feeluown is fetching songs,
         # so when we enter state_playall_start, we set play all btn text
         # to this.
-        self.play_all_btn.setText('Fetching All Songs...')
+        self.play_all_btn.setText('获取所有歌曲...')
 
     def enter_state_playall_end(self):
-        self.play_all_btn.setText('Fetching All Songs...done')
+        self.play_all_btn.setText('获取所有歌曲...done')
         self.play_all_btn.setEnabled(True)
-        self.play_all_btn.setText('Play All')
+        self.play_all_btn.setText('播放全部')
+
+    def add_tmp_button(self, button):
+        """Append text button"""
+        if button not in self._tmp_buttons:
+            # FIXME(cosven): the button inserted isn't aligned with other buttons
+            self._layout.insertWidget(len(self._tmp_buttons) + 1, button)
+            self._tmp_buttons.append(button)
 
     def _setup_ui(self):
         self._layout = QHBoxLayout(self)
@@ -65,6 +69,15 @@ class SongsTableToolbar(QWidget):
         self._layout.addStretch(0)
         self._layout.addWidget(self.filter_albums_combobox)
 
+    def _before_change_mode(self):
+        """filter all filter buttons"""
+        for button in self._tmp_buttons:
+            self._layout.removeWidget(button)
+            button.close()
+        self._tmp_buttons.clear()
+        self.filter_albums_combobox.hide()
+        self.play_all_btn.hide()
+
     def on_albums_filter_changed(self, index):
         # ['所有', '专辑', '单曲与EP', '现场', '合辑']
         if index == 0:
